function Mouse_track(newVarName,titleFmt)
% MOUSE_TRACK Track mouse position and show coordinates in figure title.
% 
% 	MOUSE_TRACK Activates MOUSE_TRACK. Once it is active the mouse position is
% 	constantly tracked and printed on the figure title.  Clicking the
% 	mouse right button deactivates MOUSE_TRACK.
global handles
% default format for printing coordinates in title
titleFmt = '%3.8f';

% get current figure event functions
currFcn = get(gcf, 'windowbuttonmotionfcn');
currFcn2 = get(gcf, 'windowbuttondownfcn');
currTitle = get(get(gca, 'Title'), 'String');
FontSz = get(get(gca, 'Title'), 'FontSize');
x_label = get(get(gca, 'xlabel'), 'String');
y_label = get(get(gca, 'ylabel'), 'String');

% add data to figure handles
handles = guidata(gca);
if (isfield(handles,'ID') & handles.ID==1)
	disp('gtrack is already active.');
	return;
else
	handles.ID = 1;
end
handles.currFcn = currFcn;
handles.currFcn2 = currFcn2;
handles.currTitle = currTitle;
handles.theState = uisuspend(gcf);
guidata(gca, handles);

% set event functions 
set(gcf,'Pointer','crosshair');
set(gcf, 'windowbuttonmotionfcn', @gtrack_OnMouseMove);        
set(gcf, 'windowbuttondownfcn', @gtrack_OnMouseDown);          

% declare variables
xInd = 0;
yInd = 0;
clickData = [];	

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                            Nested functions                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                         Mouse move callback
function gtrack_OnMouseMove(src,evnt)

% get mouse position
pt = get(gca, 'CurrentPoint');
xInd = pt(1, 1);
yInd = pt(1, 2);

% check if it's within axes limits
xLim = get(gca, 'XLim');	
yLim = get(gca, 'YLim');

%%%%%%%%%%% Correct X- and Y-ticks %%%%%%%%%%%%%%%%%%%%%%% 
% Correction
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if xInd < xLim(1) | xInd > xLim(2)
    title(currTitle, 'FontSize',FontSz);
	return;
end
if yInd < yLim(1) | yInd > yLim(2)
    title(currTitle, 'FontSize',FontSz);
	return;
end

% update figure title
try
	title([x_label ' = \rm' num2str(xInd,titleFmt) ',   ' y_label ' = \rm' num2str(yInd,titleFmt)], 'FontSize',FontSz);
catch
	gtrack_Off()
	error('MOUSE_TRACK: Error printing coordinates.')
end

end
%--------------------------------------------------------------------------
%%                        Mouse click callback
function gtrack_OnMouseDown(src,evnt)
    
% if left click, print coordinates in MATLAB Editor
fprintf('X = %3.8f   Y = %3.8f\n',xInd,yInd);    

% if right click, terminate
if strcmp(get(gcf,'SelectionType'),'alt')
	gtrack_Off
	return
end

end
%--------------------------------------------------------------------------
%%                         Terminate callback
function gtrack_Off(src,evnt)

% restore default figure properties
handles = guidata(gca);
set(gcf, 'windowbuttonmotionfcn', handles.currFcn);
set(gcf, 'windowbuttondownfcn', handles.currFcn2);
set(gcf,'Pointer','arrow');
title(handles.currTitle, 'FontSize',FontSz);
uirestore(handles.theState);
handles.ID=0;
guidata(gca,handles);

end
%%%%%%%%%%%%%%%%%%%%%%%%%%% End nested functions %%%%%%%%%%%%%%%%%%%%%%%%%%
end % end everything